@@ -50,7 +50,6 @@ struct _XfceNotifyDaemon
     GObject parent;
 
     gint expire_timeout;
-    gboolean fade_transparency;
     gdouble initial_opacity;
     GtkCornerType notify_location;
 
@@ -213,7 +212,8 @@ xfce_notify_rootwin_watch_workarea(GdkXEvent *gxevent,
     XPropertyEvent *xevt = (XPropertyEvent *)gxevent;
 
     if(xevt->type == PropertyNotify
-       && XInternAtom(xevt->display, "_NET_WORKAREA", False) == xevt->atom)
+       && XInternAtom(xevt->display, "_NET_WORKAREA", False) == xevt->atom
+       && xndaemon->monitors_workarea)
     {
         GdkScreen *screen = gdk_event_get_screen(event);
         int screen_number = gdk_screen_get_number (screen);
@@ -236,9 +236,17 @@ xfce_notify_daemon_screen_changed(GdkScreen *screen,
 {
     XfceNotifyDaemon *xndaemon = XFCE_NOTIFY_DAEMON(user_data);
     gint j;
-    gint new_nmonitor = gdk_screen_get_n_monitors(screen);
-    gint screen_number = gdk_screen_get_number(screen);
-    gint old_nmonitor = GPOINTER_TO_INT(g_object_get_qdata(G_OBJECT(screen), XND_N_MONITORS));
+    gint new_nmonitor;
+    gint screen_number;
+    gint old_nmonitor;
+
+    if(!xndaemon->monitors_workarea || !xndaemon->reserved_rectangles)
+        /* Placement data not initialized, don't update it */
+        return;
+
+    new_nmonitor = gdk_screen_get_n_monitors(screen);
+    screen_number = gdk_screen_get_number(screen);
+    old_nmonitor = GPOINTER_TO_INT(g_object_get_qdata(G_OBJECT(screen), XND_N_MONITORS));
 
     DBG("Got 'screen-changed' signal for screen %d", screen_number);
 
@@ -312,6 +320,9 @@ xfce_notify_daemon_init(XfceNotifyDaemon *xndaemon)
                                                    (GDestroyNotify)gtk_widget_destroy);
     xndaemon->last_notification_id = 1;
 
+    xndaemon->reserved_rectangles = NULL;
+    xndaemon->monitors_workarea = NULL;
+
     xndaemon->close_timeout =
         g_timeout_add_seconds(600, (GSourceFunc) xfce_notify_daemon_close_timeout,
                               xndaemon);
@@ -320,29 +331,33 @@ xfce_notify_daemon_init(XfceNotifyDaemon *xndaemon)
 static void
 xfce_notify_daemon_finalize(GObject *obj)
 {
-    gint nscreen = gdk_display_get_n_screens(gdk_display_get_default());
-    gint i, j;
     XfceNotifyDaemon *xndaemon = XFCE_NOTIFY_DAEMON(obj);
 
-    for(i = 0; i < nscreen; ++i) {
-        GdkScreen *screen = gdk_display_get_screen(gdk_display_get_default(), i);
-        GdkWindow *groot = gdk_screen_get_root_window(screen);
-        gint nmonitor = gdk_screen_get_n_monitors(screen);
+    if(xndaemon->reserved_rectangles && xndaemon->monitors_workarea) {
+      gint nscreen, i, j;
 
-        gdk_window_remove_filter(groot, xfce_notify_rootwin_watch_workarea, xndaemon);
+      nscreen = gdk_display_get_n_screens(gdk_display_get_default());
 
-        for(j = 0; j < nmonitor; j++) {
-            if (xndaemon->reserved_rectangles[i][j])
-                g_list_free(xndaemon->reserved_rectangles[i][j]);
-        }
+      for(i = 0; i < nscreen; ++i) {
+          GdkScreen *screen = gdk_display_get_screen(gdk_display_get_default(), i);
+          GdkWindow *groot = gdk_screen_get_root_window(screen);
+          gint nmonitor = gdk_screen_get_n_monitors(screen);
 
-        g_free(xndaemon->reserved_rectangles[i]);
-        g_free(xndaemon->monitors_workarea[i]);
+          gdk_window_remove_filter(groot, xfce_notify_rootwin_watch_workarea, xndaemon);
+
+          for(j = 0; j < nmonitor; j++) {
+              if (xndaemon->reserved_rectangles[i][j])
+                  g_list_free(xndaemon->reserved_rectangles[i][j]);
+          }
+
+          g_free(xndaemon->reserved_rectangles[i]);
+          g_free(xndaemon->monitors_workarea[i]);
+      }
+
+      g_free(xndaemon->reserved_rectangles);
+      g_free(xndaemon->monitors_workarea);
     }
 
-    g_free(xndaemon->reserved_rectangles);
-    g_free(xndaemon->monitors_workarea);
-
     g_tree_destroy(xndaemon->active_notifications);
 
     if(xndaemon->settings)
@@ -846,8 +861,6 @@ notify_notify(XfceNotifyDaemon *xndaemon,
         xfce_notify_window_set_body(window, body);
         xfce_notify_window_set_actions(window, actions);
         xfce_notify_window_set_expire_timeout(window, expire_timeout);
-        xfce_notify_window_set_fade_transparent(window,
-                                                xndaemon->fade_transparency);
         xfce_notify_window_set_opacity(window, xndaemon->initial_opacity);
 
         *OUT_id = replaces_id;
@@ -856,8 +869,6 @@ notify_notify(XfceNotifyDaemon *xndaemon,
                                                                         app_icon,
                                                                         expire_timeout,
                                                                         actions));
-        xfce_notify_window_set_fade_transparent(window,
-                                                xndaemon->fade_transparency);
         xfce_notify_window_set_opacity(window, xndaemon->initial_opacity);
 
         *OUT_id = xfce_notify_daemon_generate_id(xndaemon);
@@ -1086,9 +1097,6 @@ xfce_notify_daemon_settings_changed(XfconfChannel *channel,
                                  ? g_value_get_int(value) : -1;
         if(xndaemon->expire_timeout != -1)
             xndaemon->expire_timeout *= 1000;
-    } else if(!strcmp(property, "/fade-transparency")) {
-        xndaemon->fade_transparency = G_VALUE_TYPE(value)
-                                    ? g_value_get_boolean(value) : TRUE;
     } else if(!strcmp(property, "/initial-opacity")) {
         xndaemon->initial_opacity = G_VALUE_TYPE(value)
                                   ? g_value_get_double(value) : 0.9;
@@ -1159,9 +1167,6 @@ xfce_notify_daemon_load_config(XfceNotifyDaemon *xndaemon,
     if(xndaemon->expire_timeout != -1)
         xndaemon->expire_timeout *= 1000;
 
-    xndaemon->fade_transparency = xfconf_channel_get_bool(xndaemon->settings,
-                                                        "/fade-transparency",
-                                                        TRUE);
     xndaemon->initial_opacity = xfconf_channel_get_double(xndaemon->settings,
                                                         "/initial-opacity",
                                                         0.9);
